%%
%% Data common for all states (HZP/HFP), all assembly types and grid + control
%% rod combinations.
%%

include "../includes/assembly_commons.inc"
include "../includes/rods.inc"
include "../includes/materials.inc"
include "../includes/fuels.inc"
include "../includes/tutorial_branch_b_cards.inc"
include "../includes/tutorial_branch_h_cards.inc"
include "../includes/tutorial_coefmatrices.inc"
include "../includes/tutorial_water_compositions.inc"

% --- Run parameters
dep butot 0.1 0.2 0.3 0.6 1 1.5 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 23 25 27 29 33 37 41

% --- Use predictor corrector LE/LI with 10+10 burnup steps
set pcc leli 10 10

% --- Cross section data library file path:
set acelib "s2v0_jeff32.xsdata"

% --- Decay data library needs to be specified for burnup calculations
set declib "sss_jeff31.dec"

% --- Fission yield library
set nfylib "sss_jeff31.nfy"

% ---Neutron population: 100000 neutrons per cycle, 200 active / 50 inactive cycles
set pop 100000 200 50
set outp 200

% --- Radially reflective boundary conditions
set bc 2

% --- Microgroup and macrogroup structures
set micro cas70_ext 2
set nfg cas8_ext

% --- Leakage correction
set fum cas70_ext 2 f 3

% --- Fission poison data
%     system (1/4 assembly) total area 115.60 cm2
set poi 1 115.60

% --- Microdepletion data for the plutonium chain
% set mdep UNI VOL N MAT1 MAT2 ... MATN
%          ZAI1 MT1
%          ZAI2 MT2
%          ...

set mdep 0 115.60 0
922380 16 922380 18 922380 102
932390 16 932390 18 932390 102
942390 16 942390 18 942390 102

% --- Group constant generation universe
set gcu 0

% --- Assembly discontinuity factors, n-w are equivalent as are s-e
set adf 0 sBound2D nwse

% --- Equilibrium xenon
set xenon 1

% --- Power density (kw/gU)
set powdens 0.010707

% --- Depletion zone division
div F1400 sep 1  subr -2 0.0 0.37950 0.40950 % Separate the outermost 0.3 mm to its own ring
div F1500 sep 1  subr -2 0.0 0.37950 0.40950 % Separate the outermost 0.3 mm to its own ring
div F1800 sep 1  subr -2 0.0 0.37950 0.40950 % Separate the outermost 0.3 mm to its own ring
div F2400 sep 1  subr -2 0.0 0.37950 0.40950 % Separate the outermost 0.3 mm to its own ring
div F1506 sep 1  subr 10 0.0 0.40950         % Use 10 rings of equal volume for gd-fuel
div F1806 sep 1  subr 10 0.0 0.40950         % Use 10 rings of equal volume for gd-fuel
div F2405 sep 1  subr 10 0.0 0.40950         % Use 10 rings of equal volume for gd-fuel
div F2409 sep 1  subr 10 0.0 0.40950         % Use 10 rings of equal volume for gd-fuel

% --- Doppler-broadening rejection correction
set dbrc 0.1e-6 1e-3 92234.00c 92235.00c 92238.00c 94239.00c 94240.00c

% --- Unresolved resonance probability table sampling
set ures 1

% --- No reproducibility (faster)
set repro 0

% --- Private scoring buffer, private results array (faster)
set shbuf 0 0

% --- Cumulative migration method (CMM) for calculation of diffusion coefficients
set cmm 1