import numpy as np

from krakentools.groupconstants.genpoly.definitions import FitVariables
from krakentools.CoreLattice import CoreLattice
from krakentools.serpent import read_all_gc_results

###############################################################
# --- Creates surfaces, universes, set gcu and set adf cards ##
#     for reflector homogenization                           ##
###############################################################

# --- Core lattice definition from Serpent input
#     Lattice type, size, pitch and origin are taken from here

core_lattice = "lat c1.1  1  0.0 0.0 9 9  21.50364"


# --- Core loading pattern (lattice elements) from Serpent input

core_loading = """XX XX XX XX XX XX XX XX XX
                  XX XX XX XX XX XX XX XX XX
                  XX XX XX XX XX XX A5 XX XX
                  XX XX XX XX XX A2 A3 A4 XX
                  XX XX XX XX A1 A2 A2 A6 XX
                  XX XX XX XX XX XX XX XX XX
                  XX XX XX XX XX XX XX XX XX
                  XX XX XX XX XX XX XX XX XX
                  XX XX XX XX XX XX XX XX XX"""

# --- Create dictionaries linking assemblies to their infinite lattice .coe
#     and _res.m files

assemblies = ["A4", "A5", "A6"]

# --- List of strings indicating an empty (non-fueled) position in the
#     loading pattern

core_empty_pos_names = ["XX"]

# --- Core symmetry card from Serpent input or an empty string literal: ""
#     The symmetry of the case is taken from here

core_symmetry = "set usym core 3 2 0.0 0.0 315 45"

##############################################################################
##############################################################################
##############################################################################

### Create a separate object

cl_object = CoreLattice()

### Parse the data

cl_object.build_model(core_lattice,
                      core_loading,
                      core_empty_pos_names,
                      core_symmetry,
                      subdiv_xy=2)

print(cl_object)

### Write files

cl_object.write_serpent_radial_reflector_files("./reflector_radial/")