import numpy as np

from krakentools.groupconstants.genpoly.definitions import FitVariables
from krakentools.Node import NodeShapes
from krakentools.reflectorhg import AxialReflectorModel
from krakentools.serpent import read_all_gc_results

###############################################################
###############################################################

num_group = 2

if num_group == 8:
    condensation_list = None
elif num_group == 4:
    condensation_list = [0, 1, 2, 2, 3, 3, 3, 3]
elif num_group == 2:
    condensation_list = [0, 0, 0, 0, 1, 1, 1, 1]
else:
    raise RuntimeError("Incorrect number of groups")

# --- Choose the fit to apply

my_fit = np.zeros((2, len(FitVariables)))
my_fit[0, FitVariables.DCO.value] = 1     # --- First order term for coolant density
my_fit[1, FitVariables.DCO.value] = 2     # --- Second order term for coolant density

# --- Set the nominal point (everything is zero by default)
#     The Serpent results are sorted to nominals and variations based on these
#     definitiions

nom_point = np.zeros((len(FitVariables)))

# --- Set some nominal values

nom_point[FitVariables.TFU.value] = 561.0
nom_point[FitVariables.TCO.value] = 404.15
nom_point[FitVariables.DCO.value] = 0.9342
nom_point[FitVariables.BOR.value] = 0.0

###############################################################
###############################################################

# --- Get all node branches

node_branches = read_all_gc_results("./reflector_axial/Serpent.inp")

# --- Condense if needed

if condensation_list:
    new_branches = []
    for nb in node_branches:
        new_branches.append(nb.give_condensed_version(condensation_list))
    node_branches = new_branches

###############################################################
###############################################################

my_model = AxialReflectorModel(NodeShapes.SQUARE, 21.50364, (-16.748, -1.748, 0.0), (100.0, 104.007, 118.719))

# --- Link data from node branches

my_model.link_reflector_data(node_branches)

# --- Ants 3D single node simulations

my_model.solve_ants_nodes(n_proc=4)

# --- Calculate DFs

my_model.calculate_reflector_dfs_from_data()

# --- Write to file

my_model.write_gen_poly(f"./gc/{num_group}g_axial.xs", nom_point, fit=my_fit, version=3)
